<?php

namespace Shopping\Manufacturer\Policies;

use Litepie\User\Contracts\UserPolicy;
use Shopping\Manufacturer\Models\Manufacturer;

class ManufacturerPolicy
{

    /**
     * Determine if the given user can view the manufacturer.
     *
     * @param UserPolicy $user
     * @param Manufacturer $manufacturer
     *
     * @return bool
     */
    public function view(UserPolicy $user, Manufacturer $manufacturer)
    {
        if ($user->canDo('manufacturer.manufacturer.view') && $user->isAdmin()) {
            return true;
        }

        return $manufacturer->user_id == user_id() && $manufacturer->user_type == user_type();
    }

    /**
     * Determine if the given user can create a manufacturer.
     *
     * @param UserPolicy $user
     * @param Manufacturer $manufacturer
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('manufacturer.manufacturer.create');
    }

    /**
     * Determine if the given user can update the given manufacturer.
     *
     * @param UserPolicy $user
     * @param Manufacturer $manufacturer
     *
     * @return bool
     */
    public function update(UserPolicy $user, Manufacturer $manufacturer)
    {
        if ($user->canDo('manufacturer.manufacturer.edit') && $user->isAdmin()) {
            return true;
        }

        return $manufacturer->user_id == user_id() && $manufacturer->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given manufacturer.
     *
     * @param UserPolicy $user
     * @param Manufacturer $manufacturer
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Manufacturer $manufacturer)
    {
        return $manufacturer->user_id == user_id() && $manufacturer->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given manufacturer.
     *
     * @param UserPolicy $user
     * @param Manufacturer $manufacturer
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Manufacturer $manufacturer)
    {
        if ($user->canDo('manufacturer.manufacturer.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given manufacturer.
     *
     * @param UserPolicy $user
     * @param Manufacturer $manufacturer
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Manufacturer $manufacturer)
    {
        if ($user->canDo('manufacturer.manufacturer.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
